``pulp_container`` Plugin
=========================

.. figure:: https://github.com/pulp/pulp_container/actions/workflows/nightly.yml/badge.svg?branch=main
 :alt: Container Nightly CI/CD

This is the ``pulp_container`` Plugin for `Pulp Project
3.0+ <https://pypi.python.org/pypi/pulpcore/>`__. This plugin provides Pulp with support for container
images, similar to the pulp_docker plugin for Pulp 2.

For more information, please see the `documentation
<https://docs.pulpproject.org/pulp_container/>`_ or the `Pulp project page
<https://pulpproject.org>`_.

How to File an Issue
--------------------

`New pulp_container issue <https://github.com/pulp/pulp_container/issues/new>`_.

.. warning::
  Is this security related? If so, please follow the `Security Disclosures <https://docs.pulpproject.org/pulpcore/bugs-features.html#security-bugs>`_ procedure.
